@@ -97,6 +97,7 @@ Application::Application(int& argc, char** argv):
     argv_ = argv;
 
     setApplicationVersion(QStringLiteral(PCMANFM_QT_VERSION));
+    setWindowIcon(QIcon::fromTheme(QStringLiteral("pcmanfm-qt")));
 
     underWayland_ = QGuiApplication::platformName() == QStringLiteral("wayland");
 
@@ -853,11 +854,15 @@ void Application::updateFromSettings() {
     }
 }
 
-void Application::updateDesktopsFromSettings(bool changeSlide) {
+void Application::updateDesktopsFromSettings(bool changeSlide, bool allowShortcutRemoval) {
+// Desktop shortcuts should be removed only explicitly (e.g., through the Preferences dialog)
+// and only for the first desktop, not when desktops are created or a general setting changes.
     QVector<DesktopWindow*>::iterator it;
     for(it = desktopWindows_.begin(); it != desktopWindows_.end(); ++it) {
         DesktopWindow* desktopWin = static_cast<DesktopWindow*>(*it);
-        desktopWin->updateFromSettings(settings_, changeSlide);
+        desktopWin->updateFromSettings(settings_,
+                                       changeSlide,
+                                       allowShortcutRemoval && it == desktopWindows_.begin());
     }
 }
 
@@ -988,7 +993,8 @@ void Application::onScreenRemoved(QScreen* oldScreen) {
             int n = desktopWindows_.size();
             for(int i = 0; i < n; ++i) {
                 DesktopWindow* window = desktopWindows_.at(i);
-                if(window->getDesktopScreen() == oldScreen) {
+                auto desktopScr = window->getDesktopScreen();
+                if(desktopScr == nullptr || desktopScr == oldScreen) {
                     desktopWindows_.remove(i);
                     delete window;
                     break;
