@@ -51,7 +51,7 @@ DesktopPreferencesDialog::DesktopPreferencesDialog(QWidget* parent, Qt::WindowFl
   ui.setupUi(this);
 
   // setup wallpaper modes
-  connect(ui.wallpaperMode, static_cast<void (QComboBox::*)(int)>(&QComboBox::currentIndexChanged), this, &DesktopPreferencesDialog::onWallpaperModeChanged);
+  connect(ui.wallpaperMode, &QComboBox::currentIndexChanged, this, &DesktopPreferencesDialog::onWallpaperModeChanged);
   ui.wallpaperMode->addItem(tr("Fill with background color only"), DesktopWindow::WallpaperNone);
   ui.wallpaperMode->addItem(tr("Stretch to fill the entire screen"), DesktopWindow::WallpaperStretch);
   ui.wallpaperMode->addItem(tr("Stretch to fit the screen"), DesktopWindow::WallpaperFit);
@@ -144,6 +144,8 @@ DesktopPreferencesDialog::DesktopPreferencesDialog(QWidget* parent, Qt::WindowFl
 
   ui.allSticky->setChecked(settings.allSticky());
 
+  ui.noItemTooltip->setChecked(settings.desktopNoTooltip());
+
   resize(sizeHint()); // show it compact
 }
 
@@ -169,10 +171,10 @@ void DesktopPreferencesDialog::lockMargins(bool lock) {
   ui.vMargin->setDisabled(lock);
   if(lock) {
     ui.vMargin->setValue(ui.hMargin->value());
-    connect(ui.hMargin, static_cast<void (QSpinBox::*)(int)>(&QSpinBox::valueChanged), ui.vMargin, &QSpinBox::setValue);
+    connect(ui.hMargin, &QSpinBox::valueChanged, ui.vMargin, &QSpinBox::setValue);
   }
   else
-    disconnect(ui.hMargin, static_cast<void (QSpinBox::*)(int)>(&QSpinBox::valueChanged), ui.vMargin, &QSpinBox::setValue);
+    disconnect(ui.hMargin, &QSpinBox::valueChanged, ui.vMargin, &QSpinBox::setValue);
 }
 
 void DesktopPreferencesDialog::applySettings()
@@ -228,18 +230,22 @@ void DesktopPreferencesDialog::applySettings()
 
   settings.setAllSticky(ui.allSticky->isChecked());
 
+  settings.setDesktopNoTooltip(ui.noItemTooltip->isChecked());
+
   settings.save();
 }
 
 void DesktopPreferencesDialog::onApplyClicked()
 {
   applySettings();
-  static_cast<Application*>(qApp)->updateDesktopsFromSettings();
+  static_cast<Application*>(qApp)->updateDesktopsFromSettings(true, // change slide
+                                                              true); // allow shortcut removal
 }
 
 void DesktopPreferencesDialog::accept() {
   applySettings();
-  static_cast<Application*>(qApp)->updateDesktopsFromSettings(false); // don't change slide wallpaper on clicking OK
+  static_cast<Application*>(qApp)->updateDesktopsFromSettings(false, // do not change slide
+                                                              true); // allow shortcut removal
   QDialog::accept();
 }
 
@@ -311,7 +317,7 @@ void DesktopPreferencesDialog::onBrowseClicked() {
 }
 
 void DesktopPreferencesDialog::onFolderBrowseClicked() {
-  QFileDialog dlg;
+  QFileDialog dlg(this);
   dlg.setAcceptMode(QFileDialog::AcceptOpen);
   dlg.setFileMode(QFileDialog::Directory);
   dlg.setOption(QFileDialog::ShowDirsOnly);
@@ -337,7 +343,7 @@ void DesktopPreferencesDialog::onFolderBrowseClicked() {
 
 void DesktopPreferencesDialog::onBrowseDesktopFolderClicked()
 {
-  QFileDialog dlg;
+  QFileDialog dlg(this);
   dlg.setAcceptMode(QFileDialog::AcceptOpen);
   dlg.setAcceptMode(QFileDialog::AcceptOpen);
   dlg.setFileMode(QFileDialog::Directory);
