@@ -801,17 +801,16 @@ void MainWindow::updateRecenMenu() {
     int w = 150 * metrics.horizontalAdvance(QLatin1Char(' ')); // for eliding long texts
     for(int i = 0; i < recentNumber; ++i) {
         if(i < recentSize) {
-            auto fileName = recentFiles.at(i);
-            actions.at(i)->setText(metrics.elidedText(fileName, Qt::ElideMiddle, w));
+            actions.at(i)->setText(metrics.elidedText(recentFiles.value(i).replace(QLatin1Char('&'), QLatin1String("&&")).replace(QLatin1Char('\t'), QLatin1Char(' ')), Qt::ElideMiddle, w));
             QIcon icon;
-            auto mimeType = Fm::MimeType::guessFromFileName(fileName.toLocal8Bit().constData());
+            auto mimeType = Fm::MimeType::guessFromFileName(recentFiles.at(i).toLocal8Bit().constData());
             if(!mimeType->isUnknownType()) {
                 if(auto icn = mimeType->icon()) {
                     icon = icn->qicon();
                 }
             }
             actions.at(i)->setIcon(icon);
-            actions.at(i)->setData(fileName);
+            actions.at(i)->setData(recentFiles.at(i));
             actions.at(i)->setVisible(true);
         }
         else {
@@ -1521,11 +1520,11 @@ void MainWindow::updateViewMenuForCurrentPage() {
     updatingViewMenu_ = false;
 }
 
-// Update the enabled state of Edit actions for selected files
-void MainWindow::updateEditSelectedActions() {
-    bool hasAccessible(false);
-    bool hasDeletable(false);
-    int renamable(0);
+// Update the enabled state of File and Edit actions for selected files
+void MainWindow::updateSelectedActions() {
+    bool hasAccessible = false;
+    bool hasDeletable = false;
+    int renamable = 0;
     if(TabPage* page = currentPage()) {
         auto files = page->selectedFiles();
         for(auto& file: files) {
@@ -1542,6 +1541,7 @@ void MainWindow::updateEditSelectedActions() {
                 break;
             }
         }
+        ui.actionFileProperties->setEnabled(files.size() > 0);
         ui.actionCopyFullPath->setEnabled(files.size() == 1);
     }
     ui.actionCopy->setEnabled(hasAccessible);
@@ -1593,8 +1593,8 @@ void MainWindow::updateUIForCurrentPage(bool setFocus) {
         updateStatusBarForCurrentPage();
     }
 
-    // also update the enabled state of Edit actions
-    updateEditSelectedActions();
+    // also update the enabled state of File and Edit actions
+    updateSelectedActions();
     bool isWritable(false);
     bool isNative(false);
     if(tabPage && tabPage->folder()) {
@@ -1715,7 +1715,7 @@ void MainWindow::onTabPageStatusChanged(int type, QString statusText) {
 
     // Since TabPage::statusChanged is always emitted after View::selChanged,
     // there is no need to connect a separate slot to the latter signal
-    updateEditSelectedActions();
+    updateSelectedActions();
 }
 
 void MainWindow::onTabPageSortFilterChanged() { // NOTE: This may be called from context menu too.
@@ -1887,7 +1887,7 @@ void MainWindow::on_actionRename_triggered() {
     }
     if(!files.empty()) {
         for(auto& file: files) {
-            if(!Fm::renameFile(file, nullptr)) {
+            if(!Fm::renameFile(file, this)) {
                 break;
             }
         }
