@@ -21,6 +21,7 @@
 #include "preferencesdialog.h"
 #include "application.h"
 #include "settings.h"
+#include <QPushButton>
 #include <QMenu>
 #include <QDir>
 #include <QHash>
@@ -59,6 +60,8 @@ PreferencesDialog::PreferencesDialog(const QString& activePage, QWidget* parent)
     selectPage(activePage);
     adjustSize();
 
+    connect(ui.buttonBox->button(QDialogButtonBox::Apply), &QPushButton::clicked, this, &PreferencesDialog::applySettings);
+
     if(static_cast<Application*>(qApp)->underWayland()) {
         ui.suCommand->setEnabled(false);
         ui.suLabel->setEnabled(false);
@@ -365,7 +368,7 @@ void PreferencesDialog::initFromSettings() {
     initVolumePage(settings);
     initAdvancedPage(settings);
 
-    connect(ui.clearSearchHistory, &QAbstractButton::clicked, [this, &settings] {
+    connect(ui.clearSearchHistory, &QAbstractButton::clicked, this, [&settings] {
         settings.clearSearchHistory();
     });
 }
@@ -531,10 +534,10 @@ void PreferencesDialog::lockMargins(bool lock) {
     ui.vMargin->setDisabled(lock);
     if(lock) {
         ui.vMargin->setValue(ui.hMargin->value());
-        connect(ui.hMargin, static_cast<void (QSpinBox::*)(int)>(&QSpinBox::valueChanged), ui.vMargin, &QSpinBox::setValue);
+        connect(ui.hMargin, &QSpinBox::valueChanged, ui.vMargin, &QSpinBox::setValue);
     }
     else {
-        disconnect(ui.hMargin, static_cast<void (QSpinBox::*)(int)>(&QSpinBox::valueChanged), ui.vMargin, &QSpinBox::setValue);
+        disconnect(ui.hMargin, &QSpinBox::valueChanged, ui.vMargin, &QSpinBox::setValue);
     }
 }
 
